@@ -8,11 +8,15 @@ from . import tools
 from . import constitution
 from . import solve
 from . import region
+from . import mechanics
 
 from .region import (
     Region,
+    RegionBoundary,
     RegionQuad,
     RegionHexahedron,
+    RegionQuadBoundary,
+    RegionHexahedronBoundary,
     RegionConstantQuad,
     RegionConstantHexahedron,
     RegionQuadraticHexahedron,
@@ -26,22 +30,24 @@ from .region import (
     RegionLagrange,
 )
 from ._assembly import (
-    IntegralForm,
-    IntegralFormMixed,
-    IntegralFormAxisymmetric,
-    LinearForm,
-    BilinearForm,
-    LinearFormMixed,
-    BilinearFormMixed,
+    # IntegralForm,
+    IntegralFormMixed as IntegralForm,
+    # IntegralFormAxisymmetric,
+    # LinearForm,
+    # BilinearForm,
+    # LinearFormMixed as LinearForm,
+    # BilinearFormMixed as BilinearForm,
+    # BaseForm,
+    Form,
 )
 from ._basis import (
-    Basis,
-    BasisMixed,
+    BasisMixed as Basis,
 )
 from ._field import (
     Field,
     FieldAxisymmetric,
-    FieldMixed,
+    FieldContainer,
+    FieldsMixed,
 )
 from .dof import Boundary
 
@@ -75,6 +81,7 @@ from .element import (
 )
 from .quadrature import (
     GaussLegendre,
+    GaussLegendreBoundary,
     Triangle as TriangleQuadrature,
     Tetrahedron as TetrahedronQuadrature,
 )
@@ -92,7 +99,6 @@ from .constitution import (
     LineChange,
     AreaChange,
     VolumeChange,
-    MatadiMaterial,
 )
 from .tools import (
     newtonrhapson,
@@ -100,6 +106,11 @@ from .tools import (
     topoints,
     project,
 )
+from .mechanics import (
+    SolidBody,
+    SolidBodyPressure,
+    SolidBodyTensor,
+)
 
 __all__ = [
     "__version__",
