@@ -1,10 +1,13 @@
 from ._mesh import Mesh
 from ._tools import (
     expand,
-    rotation_matrix,
     rotate,
     revolve,
     sweep,
+    mirror,
+    triangulate,
+)
+from ._convert import (
     convert,
     collect_edges,
     collect_faces,
