@@ -32,7 +32,7 @@ import numpy as np
 from scipy.sparse.linalg import spsolve
 
 from ..math import norm
-from .._assembly import IntegralForm, IntegralFormMixed
+from .._assembly import IntegralFormMixed
 from .. import solve as fesolve
 
 
@@ -46,69 +46,88 @@ class Result:
         self.iterations = iterations
 
 
-def fun(x, umat, parallel=False, grad=True, add_identity=True, sym=False):
+def fun_bodies(bodies, x=None, parallel=False, jit=False):
     "Force residuals from assembly of equilibrium (weak form)."
 
-    if "mixed" in str(type(x)):
+    # init keyword arguments
+    kwargs = {"parallel": parallel, "jit": jit}
 
-        L = IntegralFormMixed(
-            fun=umat.gradient(
-                *x.extract(grad=grad, add_identity=add_identity, sym=sym)
-            ),
-            v=x,
-            dV=x[0].region.dV,
-        )
+    # assemble vector of first body
+    vector = bodies[0].assemble.vector(field=x, **kwargs)
 
-    else:
+    # loop over other bodies
+    for body in bodies[1:]:
 
-        L = IntegralForm(
+        # assemble vector
+        r = body.assemble.vector(field=x, **kwargs)
+
+        # check and reshape vector
+        if r.shape != vector.shape:
+            r.resize(*vector.shape)
+
+        # add vector
+        vector += r
+
+    return vector.toarray()[:, 0]
+
+
+def jac_bodies(bodies, parallel=False, jit=False):
+    "Tangent stiffness matrix from assembly of linearized equilibrium."
+
+    # init keyword arguments
+    kwargs = {"parallel": parallel, "jit": jit}
+
+    # assemble matrix of first body
+    matrix = bodies[0].assemble.matrix(**kwargs)
+
+    # loop over other bodies
+    for body in bodies[1:]:
+
+        # assemble matrix
+        K = body.assemble.matrix(**kwargs)
+
+        # check and reshape matrix
+        if K.shape != matrix.shape:
+            K.resize(*matrix.shape)
+
+        # add matrix
+        matrix += K
+
+    return matrix
+
+
+def fun(x, umat, parallel=False, jit=False, grad=True, add_identity=True, sym=False):
+    "Force residuals from assembly of equilibrium (weak form)."
+
+    return (
+        IntegralFormMixed(
             fun=umat.gradient(x.extract(grad=grad, add_identity=add_identity, sym=sym)),
             v=x,
             dV=x.region.dV,
-            grad_v=True,
         )
-
-    return L.assemble(parallel=parallel).toarray()[:, 0]
+        .assemble(parallel=parallel, jit=jit)
+        .toarray()[:, 0]
+    )
 
 
-def jac(x, umat, parallel=False, grad=True, add_identity=True, sym=False):
+def jac(x, umat, parallel=False, jit=False, grad=True, add_identity=True, sym=False):
     "Tangent stiffness matrix from assembly of linearized equilibrium."
 
-    if "mixed" in str(type(x)):
-
-        a = IntegralFormMixed(
-            fun=umat.hessian(*x.extract(grad=grad, add_identity=add_identity, sym=sym)),
-            v=x,
-            dV=x[0].region.dV,
-            u=x,
-        )
-
-    else:
-
-        a = IntegralForm(
-            fun=umat.hessian(x.extract(grad=grad, add_identity=add_identity, sym=sym)),
-            v=x,
-            dV=x.region.dV,
-            u=x,
-            grad_v=True,
-            grad_u=True,
-        )
-
-    return a.assemble(parallel=parallel)
+    return IntegralFormMixed(
+        fun=umat.hessian(x.extract(grad=grad, add_identity=add_identity, sym=sym)),
+        v=x,
+        dV=x.region.dV,
+        u=x,
+    ).assemble(parallel=parallel, jit=jit)
 
 
 def solve(A, b, x, dof1, dof0, offsets=None, ext0=None, solver=spsolve):
     "Solve partitioned system."
 
     system = fesolve.partition(x, A, dof1, dof0, -b)
-
     dx = fesolve.solve(*system, ext0, solver=solver)
 
-    if "mixed" in str(type(x)):
-        return np.split(dx, offsets)
-
-    else:
-        return dx
+    return dx
 
 
 def check(dx, x, f, tol):
@@ -117,7 +136,7 @@ def check(dx, x, f, tol):
 
 
 def newtonrhapson(
-    x0,
+    x0=None,
     fun=fun,
     jac=jac,
     solve=solve,
@@ -130,9 +149,9 @@ def newtonrhapson(
     kwargs_check={},
     tol=np.sqrt(np.finfo(float).eps),
     umat=None,
+    bodies=None,
     dof1=None,
     dof0=None,
-    offsets=None,
     ext0=None,
     solver=spsolve,
     export_jac=False,
@@ -171,15 +190,21 @@ def newtonrhapson(
     if timing:
         time_start = perf_counter()
 
-    # copy x0
-    x = x0
-    # x = deepcopy(x0)
+    if x0 is not None:
+        # copy x0
+        x = x0
+    else:
+        # copy field of body
+        x = bodies[0].field
 
     if umat is not None:
         kwargs["umat"] = umat
 
     # pre-evaluate function at given unknowns "x"
-    f = fun(x, *args, **kwargs)
+    if bodies is not None:
+        f = fun_bodies(bodies, x, *args, **kwargs)
+    else:
+        f = fun(x, *args, **kwargs)
 
     if verbose:
         print()
@@ -193,13 +218,16 @@ def newtonrhapson(
     for iteration in range(maxiter):
 
         # evaluate jacobian at unknowns "x"
-        K = jac(x, *args, **kwargs)
+        if bodies is not None:
+            K = jac_bodies(bodies, *args, **kwargs)
+        else:
+            K = jac(x, *args, **kwargs)
 
         # solve linear system and update solution
         sig = inspect.signature(solve)
 
-        keys = ["x", "dof1", "dof0", "offsets", "ext0", "solver"]
-        values = [x, dof1, dof0, offsets, ext0, solver]
+        keys = ["x", "dof1", "dof0", "ext0", "solver"]
+        values = [x, dof1, dof0, ext0, solver]
 
         for key, value in zip(keys, values):
 
@@ -210,7 +238,10 @@ def newtonrhapson(
         x = update(x, dx)
 
         # evaluate function at unknowns "x"
-        f = fun(x, *args, **kwargs)
+        if bodies is not None:
+            f = fun_bodies(bodies, x, *args, **kwargs)
+        else:
+            f = fun(x, *args, **kwargs)
 
         # check success of solution
         norm, success = check(dx, x, f, tol, **kwargs_check)
